#
# Please submit bugfixes or comments via https://bugs.links2linux.org/
#
# Please edit kodi.spec and kodi.changes only. *-noX.* files are generated from kodi.* files with the pre_checkin.sh script
#


%define _libtag_ver %(version="`rpm -q --qf '%{VERSION}' libtag-devel`"; echo "$version")
%define _kodi_addons_dir %{_datadir}/kodi/addons
%define ffmpeg_archive_name 2.4.6-Helix
%define pvr_addons_archive_name Helix_rc3
%define kodi_version Helix

%bcond_without enable_rpi_build
%bcond_without enable_rpi_omxplayer

# kodi can be built without X support when openGL ES is used (mainly used on ARM boards used as media center)
%define noX_build ("%{name}" == "kodi-noX")
%if %{noX_build}
# no X build needs openGL ES
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%ifarch %{arm} armv6l armv6hl
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%bcond_without enable_opengl
%bcond_with enable_opengles
%endif
%endif

Name:        kodi
Version:     14.2
Release:     2.7
Summary:     Kodi Media center
License:     GPL-2.0+ and GPL-3.0+
Group:       Productivity/Multimedia/Video/Players
Url:         http://kodi.tv/

Source0:     %{version}-%{kodi_version}.tar.gz
Source1:     https://github.com/opdenkamp/xbmc-pvr-addons/archive/%{pvr_addons_archive_name}.tar.gz
Source2:     https://github.com/xbmc/FFmpeg/archive/%{ffmpeg_archive_name}.tar.gz
# PATCH-FIX-OPENSUSE -- enable all pvr addons
Patch0:      pvr-addons-enable-all.patch
Patch1:      no-xbmc-symbolic-link.patch
# Raspberry Pi (armv6): omxplayer 3D support is only available for non X11 KODI
#Patch2:     disable_omxplayer_3d_support.patch
BuildRoot:   %{_tmppath}/%{name}-%{version}-build
ExcludeArch: ppc64
%if %{noX_build}
Conflicts:   kodi
%else
Conflicts:   kodi-noX
%endif
Obsoletes:   xbmc <= %{version}
Provides:    xbmc = %{version}
Conflicts:   xbmc

%if 0%{?suse_version} < 1140
BuildRequires:  hal-devel
%endif
%if 0%{?fedora} >= 14
BuildRequires:  gettext-autopoint
%else
BuildRequires:  gettext
%endif
%ifarch armv6l armv6hl
%if %{with enable_rpi_build}
%if %{with enable_rpi_omxplayer}
BuildRequires:  omxplayer
%endif
%endif
%endif

BuildRequires:  alsa-devel
BuildRequires:  avahi-devel
BuildRequires:  boost-devel
BuildRequires:  ccache
# needed to delete the fixed rpath introduced by smbclient
BuildRequires:  chrpath
BuildRequires:  cmake
BuildRequires:  curl curl-devel
BuildRequires:  desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  enca-devel
BuildRequires:  fdupes
BuildRequires:  flac-devel
BuildRequires:  flex
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  fribidi-devel
BuildRequires:  ftgl-devel
BuildRequires:  gcc-c++
%if %{with enable_opengl}
BuildRequires:  glew-devel
%endif
BuildRequires:  glibc-devel
BuildRequires:	gmp-devel
BuildRequires:  gperf
BuildRequires:  java
BuildRequires:  libSDL-devel
BuildRequires:  libSDL_image-devel
BuildRequires:  libSDL_mixer-devel
BuildRequires:  libass-devel >= 0.9.7
BuildRequires:  libbluray-devel
BuildRequires:  libbz2-devel
BuildRequires:  libcdio-devel
BuildRequires:  libcec-devel >= 2.2.0
%ifarch %ix86 x86_64
BuildRequires:  libcrystalhd-devel
%endif
BuildRequires:  libdca-devel
BuildRequires:  libdvdread-devel
BuildRequires:  libexpat-devel
BuildRequires:  libfaac-devel
#BuildRequires:  libffmpeg-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libgpg-error-devel
BuildRequires:  libhdhomerun-devel
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libmad-devel
BuildRequires:  libmicrohttpd-devel
BuildRequires:  libmodplug-devel
BuildRequires:  libmpeg2-devel
BuildRequires:  libnettle-devel
BuildRequires:  libnfs-devel
BuildRequires:  libogg-devel
BuildRequires:  libpcrecpp0
BuildRequires:  libplist-devel
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
BuildRequires:  librtmp-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  shairplay-devel
BuildRequires:  libsmbclient-devel
BuildRequires:  libssh-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtag-devel >= 1.8
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  libudev-devel
BuildRequires:  libva-devel
%if %{with enable_opengl}
BuildRequires:  libvdpau-devel
%endif
BuildRequires:  libvorbis-devel
BuildRequires:  libyajl-devel
BuildRequires:  lzo-devel
BuildRequires:  mysql-devel
BuildRequires:  nasm
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  sqlite-devel
BuildRequires:  swig
BuildRequires:  tinyxml-devel
BuildRequires:  libxml2-devel
BuildRequires:  libxslt-devel
BuildRequires:  unzip
BuildRequires:  libgnutls-devel
BuildRequires:  bluez-devel
BuildRequires:  libcap-devel
%if !%{noX_build}
BuildRequires:  xorg-x11-devel
%endif
BuildRequires:  yasm
BuildRequires:  byacc
BuildRequires:  zip
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glib-2.0)

## kodi needs the same libtag version which was used to build against
Requires:       libtag1 = %{_libtag_ver}
# kodi needs libnfs to access nfs sources, it is not automatically required
Requires:       libnfs
# glxinfo is needed to check hw accel
%if 0%{?suse_version} >= 1220
%if !%{noX_build}
Requires:       Mesa-demo-x
Requires:       xdpyinfo
%endif
%endif
%if %{with enable_opengles}
%ifnarch armv6l armv6hl
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv2-devel
%else
%if %{with enable_rpi_build}
BuildRequires:  raspberrypi-userland-devel
%else
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv2-devel
%endif
%endif
%endif

%description
KODI media center is a free cross-platform media-player jukebox and
entertainment hub.  KODI can play a spectrum of of multimedia formats,
and featuring playlist, audio visualizations, slideshow, and weather
forecast functions, together third-party plugins.

%package devel
Summary:        Kodi Media center devel files
Group:          Development/Languages/C and C++
Requires:       %{name}
BuildArch:      noarch
%if %{noX_build}
Conflicts:      kodi-devel
%else
Conflicts:      kodi-noX-devel
%endif

%description devel
Development files for the Kodi media Center

%prep
%setup -q -n xbmc-%{version}-%{kodi_version}
%patch0
%patch1
%if !%{noX_build}
#%%patch2
%endif

tar -xf %{SOURCE1}
mv xbmc-pvr-addons-%{pvr_addons_archive_name} pvr-addons
pushd pvr-addons
./bootstrap
popd

#cp %{SOURCE2} tools/depends/target/ffmpeg/ffmpeg-%{ffmpeg_archive_name}.tar.gz

# Remove build time references so build-compare can do its work
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
FAKE_BUILDDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes)

# remove it in ffmpeg archive and repackage it
tar xpfz %{SOURCE2} -C tools/depends/target/ffmpeg/
for file in tools/depends/target/ffmpeg/FFmpeg-%{ffmpeg_archive_name}/ffprobe.c tools/depends/target/ffmpeg/FFmpeg-%{ffmpeg_archive_name}/cmdutils.c; do
  sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" $file
done
tar cpfz tools/depends/target/ffmpeg/ffmpeg-%{ffmpeg_archive_name}.tar.gz -C tools/depends/target/ffmpeg/ FFmpeg-%{ffmpeg_archive_name}/
rm -r tools/depends/target/ffmpeg/FFmpeg-%{ffmpeg_archive_name}

# remove the remaining occurencies in the source tree
for file in lib/timidity/timidity/speex_a.c xbmc/Application.cpp xbmc/GUIInfoManager.cpp ; do
  sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" $file
done
for file in xbmc/interfaces/python/PythonSwig.cpp.template ; do
  sed -i -e "/PyModule_AddStringConstant.*__date__/ s/\${new Date()\.toString()}/$FAKE_BUILDDATETIME/"  $file
done

chmod +x bootstrap
./bootstrap

%build
%ifarch armv6l armv6hl
%if %{with enable_rpi_build}
export CXXFLAGS="$CXXFLAGS -I%{_includedir}/interface/vcos/pthreads -I%{_includedir}/interface/vmcs_host/linux"
%endif
%endif
%configure \
--enable-airplay \
--enable-vdpau \
--enable-vaapi \
--enable-rtmp \
--enable-libbluray \
--disable-debug \
--enable-shared \
--enable-optimizations \
--disable-static \
--enable-libcec \
--enable-alsa \
%if %{with enable_opengl}
  --enable-goom \
  --enable-vaapi \
  --enable-vdpau \
  --enable-gl \
%else
  --disable-goom \
  --disable-vaapi \
  --disable-vdpau \
  --disable-gl \
%endif
%if %{with enable_opengles}
  --enable-gles \
%else
  --disable-gles \
%endif
%ifarch armv6l armv6hl
%if %{with enable_rpi_build}
    --with-platform=raspberry-pi \
%if %{with enable_rpi_omxplayer}
      --enable-player=omxplayer \
%endif
%endif
%endif
%ifarch armv7l armv7hl
  --enable-tegra --disable-neon \
%endif
%if %{noX_build}
  --disable-x11 --disable-xrandr --disable-sdl --disable-joystick \
%endif

make %{?_smp_mflags}
#make -j1 V=0

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
# remove the doc files from unversioned /usr/share/doc/kodi, they should be in versioned docdir
rm -r %{buildroot}/%{_datadir}/doc/

# copy manpages
install -m 644 -D docs/manpages/kodi-standalone.1 %{buildroot}%{_mandir}/man1/kodi-standalone.1
install -m 644 -D docs/manpages/kodi.bin.1 %{buildroot}%{_mandir}/man1/kodi.1

# remove win32 source files
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.addon/dlfcn-win32.cpp
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.addon/dlfcn-win32.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.addon/dlfcn-win32.cpp
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.addon/dlfcn-win32.h

# remove duplicate header files
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.addon/libXBMC_addon.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.addon/libXBMC_addon.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.codec/libXBMC_codec.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.codec/libXBMC_codec.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.gui/libXBMC_gui.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.gui/libXBMC_gui.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.kodi.pvr/libXBMC_pvr.h
rm -f %{buildroot}%{_kodi_addons_dir}/library.xbmc.pvr/libXBMC_pvr.h

desktop-file-install \
 --dir=%{buildroot}%{_datadir}/applications \
 %{buildroot}%{_datadir}/applications/kodi.desktop

# delete fixed rpath from smbclient.pc - this fixes
# http://trac.kodi.tv/ticket/15497 and
# http://bugzilla.opensuse.org/show_bug.cgi?id=902421
chrpath %{buildroot}%{_libdir}/kodi/kodi.bin >/dev/null 2>&1 && \
  chrpath -d %{buildroot}%{_libdir}/kodi/kodi.bin

%fdupes %{buildroot}

%files
%defattr(-,root,root)
%doc copying.txt LICENSE.GPL docs/README.linux
%{_bindir}/kodi
%{_bindir}/xbmc
%{_bindir}/kodi-standalone
%{_bindir}/xbmc-standalone
%{_libdir}/kodi
%{_datadir}/xsessions/kodi.desktop
%{_datadir}/xsessions/xbmc.desktop
%{_datadir}/applications/kodi.desktop
%{_datadir}/icons/hicolor/*/*/*.png
%{_datadir}/kodi
%{_datadir}/kodi/FEH.py
%{_datadir}/kodi/language/*
%{_datadir}/kodi/media/*
%{_datadir}/kodi/sounds/*
%{_datadir}/kodi/system/*
%{_datadir}/kodi/userdata/*
%{_mandir}/man1/kodi.1.gz
%{_mandir}/man1/kodi-standalone.1.gz
%{_kodi_addons_dir}/metadata.album.universal/*
%{_kodi_addons_dir}/metadata.artists.universal/*
%{_kodi_addons_dir}/metadata.common.allmusic.com/*
%{_kodi_addons_dir}/metadata.common.amazon.de/*
%{_kodi_addons_dir}/metadata.common.fanart.tv/*
%{_kodi_addons_dir}/metadata.common.hdtrailers.net/*
%{_kodi_addons_dir}/metadata.common.htbackdrops.com/*
%{_kodi_addons_dir}/metadata.common.imdb.com/*
%{_kodi_addons_dir}/metadata.common.last.fm/*
%{_kodi_addons_dir}/metadata.common.musicbrainz.org/*
%{_kodi_addons_dir}/metadata.common.theaudiodb.com/*
%{_kodi_addons_dir}/metadata.common.themoviedb.org/*
%{_kodi_addons_dir}/metadata.local/*
%{_kodi_addons_dir}/metadata.musicvideos.theaudiodb.com/*
%{_kodi_addons_dir}/metadata.themoviedb.org/*
%{_kodi_addons_dir}/metadata.tvdb.com/*
%{_kodi_addons_dir}/repository.xbmc.org/*
%if %{with enable_opengl}
%{_kodi_addons_dir}/screensaver.rsxs.euphoria/*
%{_kodi_addons_dir}/screensaver.rsxs.plasma/*
%{_kodi_addons_dir}/screensaver.rsxs.solarwinds/*
%endif
%{_kodi_addons_dir}/screensaver.xbmc.builtin.black/*
%{_kodi_addons_dir}/screensaver.xbmc.builtin.dim/*
%{_kodi_addons_dir}/script.module.pil/*
%{_kodi_addons_dir}/service.xbmc.versioncheck/*
%{_kodi_addons_dir}/skin.confluence/*
%if %{with enable_opengl}
%{_kodi_addons_dir}/visualization.fishbmc/*
%endif
%{_kodi_addons_dir}/visualization.glspectrum/*
%if %{with enable_opengl}
%{_kodi_addons_dir}/visualization.goom/*
%{_kodi_addons_dir}/visualization.projectm/*
%endif
%{_kodi_addons_dir}/visualization.vortex/*
%{_kodi_addons_dir}/visualization.waveform/*
%{_kodi_addons_dir}/webinterface.default/*
%{_kodi_addons_dir}/xbmc.codec/*
%{_kodi_addons_dir}/xbmc.addon/*
%{_kodi_addons_dir}/xbmc.core/*
%{_kodi_addons_dir}/xbmc.gui/*
%{_kodi_addons_dir}/xbmc.json/*
%{_kodi_addons_dir}/xbmc.metadata/*
%{_kodi_addons_dir}/xbmc.pvr/*
%{_kodi_addons_dir}/xbmc.python/*
%{_kodi_addons_dir}/pvr.argustv/*
%{_kodi_addons_dir}/pvr.demo/*
%{_kodi_addons_dir}/pvr.dvblink/*
%{_kodi_addons_dir}/pvr.dvbviewer/*
%{_kodi_addons_dir}/pvr.hts/*
%{_kodi_addons_dir}/pvr.iptvsimple/*
%{_kodi_addons_dir}/pvr.mediaportal.tvserver/*
%{_kodi_addons_dir}/pvr.mythtv/*
%{_kodi_addons_dir}/pvr.nextpvr/*
%{_kodi_addons_dir}/pvr.njoy/*
%{_kodi_addons_dir}/pvr.vdr.vnsi/*
%{_kodi_addons_dir}/pvr.vuplus/*
%{_kodi_addons_dir}/pvr.wmc/*

%files devel
%defattr(-,root,root)
%{_includedir}/kodi
%{_includedir}/kodi/DVDDemuxPacket.h
%{_includedir}/kodi/libXBMC_addon.h
%{_includedir}/kodi/libXBMC_codec.h
%{_includedir}/kodi/libXBMC_gui.h
%{_includedir}/kodi/libXBMC_pvr.h
%{_includedir}/kodi/xbmc_addon_cpp_dll.h
%{_includedir}/kodi/xbmc_addon_dll.h
%{_includedir}/kodi/xbmc_addon_types.h
%{_includedir}/kodi/xbmc_codec_types.h
%{_includedir}/kodi/xbmc_epg_types.h
%{_includedir}/kodi/xbmc_pvr_dll.h
%{_includedir}/kodi/xbmc_pvr_types.h
%{_includedir}/kodi/xbmc_scr_dll.h
%{_includedir}/kodi/xbmc_scr_types.h
%{_includedir}/kodi/xbmc_stream_utils.hpp
%{_includedir}/kodi/xbmc_vis_dll.h
%{_includedir}/kodi/xbmc_vis_types.h
%{_includedir}/kodi/xbmc_audioenc_dll.h
%{_includedir}/kodi/xbmc_audioenc_types.h


%changelog
* Mon Apr 27 2015 aloisio@gmx.com
- Removed libhogweed2 build requirement to fix Factory/Tumbleweed
  build.
  Sat Mar 28 20:26:58 UTC 2015 - sagiben at gmail dot com
- Update to Kodi 14.2 Helix Bugfix release
  * Fix: Application stopped responding on Windows
  * Fix: Gap-less playback on MP3
  * Fix: Playback of rtmp protocol
  * Fix: Scanning of newly added episodes
  * Fix: Fix multipath source scanning
  * Fix: Loading external subtitles in some cases
  * Fix: packaging of PIL module on Android. This fixes some script error when using weather add-on
  * Fix: Fix video playback on all platform after refresh rate change
  * Fix: Various bugs that were present in PVR add-ons.
  * Fix: Save weather location
  * Fix: Fix filtering of foreign add-ons
  * Fix: ftps handling
  Sat Feb  7 18:11:31 UTC 2015 - sagiben at gmail dot com
- enable AirPlay support
  Tue Feb  3 19:53:15 UTC 2015 - sagiben at gmail dot com
- Update to Kodi 14.1 Helix Bugfix release
  * Fix: incorrect video screensize on Android AML devices
  * Fix: potential segfault when silencing audio
  * Fix: do not skip streaminfo if format is not know.
  * Fix: DXVA flickering on AMD
  * Fix: prevent possible over-flow in ALSA
  * Fix: possible sorting problems in library
  * Fix: possible problem in library navigation
  * Fix: don’t scroll text when it’s set to not do it
  * Fix: scroll text if it’s too long on spinner controls
  * Fix: don’t overlap PVR search labels
  * Fix: bug in DLNA client string on iOS
  * Fix: updated several PVR add-ons
  * Fix: remember played state of video when started from recently added
  * Fix: correct vsync on OSX
  * Fix: broken keyboard input
  * Fix: prevent crash on circular dependencies of add-ons
  * Fix: large file support on Android
  * Fix: random exiting on Android x86 builds (Nexus Player for example)
* Sat Jan 24 2015 obs@botter.cc
- Require: libnfs to access NFS sources (not automatically required)
* Fri Jan 16 2015 obs@botter.cc
- fix __date__ macro in PythonSwig.cpp.template
* Sat Jan 10 2015 obs@botter.cc
- delete RUNPATH from installed binary, fixes PM-130, referencing
  http://trac.kodi.tv/ticket/15497 and http://bugzilla.opensuse.org/show_bug.cgi?id=902421
- along the line ALSA support was included in Request #1545
* Fri Jan  9 2015 obs@botter.cc
- Require: xpdyinfo on != -noX version
* Thu Jan  8 2015 obs@botter.cc
- remove __DATE and __TIME__ from source tree and ffmpeg archive
  Fri Dec 12 06:21:30 UTC 2014 - sagiben at gmail dot com
- Update to Kodi 14.0 Helix
  * Project name was changed from XBMC to Kodi ( http://kodi.tv/introducing-kodi-14/ )
  * Different selectable keyboard layouts for the on screen keyboard.
  * Faster library scraping
  * Updated ffmpeg (2.4.4) including h.265 support
  * More control over add-ons and their updates in the add-on manager
  * "big font" size in Confluence
  * ATSC sub channels for PVR in the US
  * PVR window changes for easier navigation and new EPG views (now/next/channel)
  * Archives (zip, bin, etc) files can be directly browsed
* Wed Nov  5 2014 fisiu@opensuse.org
- Depends on xdpyinfo on x86{,-64}, fix pm#126.
  Sat Sep 13 04:41:09 UTC 2014 - sagiben at gmail dot com
- Update to 13.2
  * Bittstream conversion fix for some BD mkv iso rips
  * Fix labelcontrols with autowidth set were always marked as dirty (re-render)
  * Update included PVR add-on
  * Set “remote as keyboard” default to true for Android
  * Fix FTP TLS not working
  * Fix onplaybackstarted event for external players
  * Don’t show OSD menu DVD menu with mouse/touch
  * GetText and delete sound option for add-on developers
  * Fix overlapping subtitles
  * Fix accented letters. Example: “VARIéS” rather than “VARIÉS”
  * Prompt for master pin in case the add-on manager is locked
  * Update GUI translations
  * Update included add-ons
  * Fixed several bugs and memory leaks
* Tue Jun 10 2014 guillaume@opensuse.org
- Drop texture.patch since xbmc 13.1 does not need this fix anymore.
* Sat Jun  7 2014 fisiu@opensuse.org
- Update to 13.1:
  * Fix resume point of certain PVR items begin stale on playback.
  * Fix weirdness when certain TVs query XBMC’s UPnP server and it
    starts running a bunch of add-ons which cause popups on the XBMC
    machine.
  * Fix crash at exit while airplay is playing
  * Better recovery of VDPAU on errors.
  * Fixes for cropping of interlaced content using VDPAU.
  * Fix for FLAC tracks with large embedded images not playing.
  * Fix for crash if librtmp wasn’t available.
  * Fix for ffmpeg building on linux using later versions of librtmp.
  * Fix for broken m4a, mp4 playback with paplayer.
  * Fix for the hint text not being shown in editcontrols once unfocused.
  * Fix minor memory leak in PlayMedia builtin function.
  * Fix albumartist use in song smartplaylists.
  * Use unique client broadcast UID in the PVR api.
* Mon May 26 2014 guillaume@opensuse.org
- Fix build for non openGL builds (fix openGL ES)
- Run pre_checkin.sh script to sync xbmc-noX files
* Sat May 17 2014 fisiu@opensuse.org
- Update to 13.0 Gotham:
  * Dramatic Audio Engine Improvements
  * Improved UPnP capabilities
  * Settings Improvements
  * Making Subtitle Search Better
  * Stereoscopic 3D Rendering
  * Raspberry Pi and Android speed improvements
  * An Extended Python and JSON-RPC API for developers
  * Many minor fixes and improvements
- Add enable-external-ffmpeg.patch: build again system ffmpeg.
- Drop xbmc-12.2-subtitles.patch: fixed upstream.
- Drop samba4-fix.patch: fixed upstream.
- Drop git_rev.patch: fixed upstream.
* Mon Feb 17 2014 guillaume@opensuse.org
- Replace raspberrypi-gfx-devel package by raspberrypi-userland-devel
* Wed Feb 12 2014 guillaume@opensuse.org
- Add no X version support (mainly used by ARM boards)
  Fri Dec 27 08:44:21 UTC 2013 - sagiben at gmail dot com
- - New upstream version 12.3
* Wed Oct  2 2013 guillaume@opensuse.org
- Fix Raspberry Pi (armv6) build:
  * Add include path for raspberrypi-gfx headers
  * Add texture.patch to fix include path for XBMCTex.cpp
  * Add disable_omxplayer_3d_support.patch to disable 3D support
  from omxplayer since X11/GLES does not support it (only EGL)
* Mon Sep 16 2013 guillaume@opensuse.org
- Enable omxplayer by default (player for raspberry pi ARMv6 board)
* Mon Sep 16 2013 guillaume@opensuse.org
- Protect enable_rpi_build condition with %%ifarch armv6
  Mon Sep 16 03:06:17 UTC 2013 - sagiben at gmail dot com
- Enable MythTV pvr addon
- Set git revision
* Fri Sep 13 2013 guillaume@opensuse.org
- Add options to enable/disable openGL / openGL ES support
  * ARM default: openGL ES
  * Other arch: openGL
* Fri Sep 13 2013 guillaume@opensuse.org
- Add support for omxplayer for raspberry pi board (armv6)
* Mon Sep  9 2013 guillaume@opensuse.org
- Add support for Raspberry Pi ARM board (armv6)
* Mon Sep  9 2013 guillaume@opensuse.org
- Add libcec and airplay support
* Wed Sep  4 2013 fisiu@opensuse.org
- Add samba4-fix.patch: fix build against samba4 - enabled for
  openSUSE >= 13.1.
* Wed Sep  4 2013 fisiu@opensuse.org
- Add Requires: Mesa-demo-x for openSUSE >= 12.2, fix pm#84.
* Mon Aug 26 2013 guillaume@opensuse.org
- Make use of %%configure macro
* Fri Aug 23 2013 guillaume@opensuse.org
- Fix builds:
  * XBMC 12.2 depends on FFMPEG1, not FFMPEG2
  * crystalhd is only built for x86/x86_64
* Mon Jun  3 2013 fisiu@opensuse.org
- Add xbmc-12.2-subtitles.patch: embeded fonts' rendering fix.
  Fri May 10 16:35:39 UTC 2013 - sagiben at gmail dot com
- New upstream version 12.2
  Fri Mar 29 03:52:57 UTC 2013 - sagiben at gmail dot com
- New upstream version 12.1
* Mon Feb  4 2013 fisiu@opensuse.org
- Spec file cleanup.
- Enable support for airplay.
- Detect libtag version and use it as Requires.
* Sun Feb  3 2013 p.seiler@linuxmail.org
- small changes in the spec file for cleanness
  replaced BuildRequires to simple java
  removed outcommented stuff like BuildRequires and so on
* Fri Feb  1 2013 hvogel@opensuse.org
-Include PVR add-ons, they are the main feature of Frodo
* Fri Feb  1 2013 p.seiler@linuxmail.org
- added explizit libtag-devel 1.8 requirement to prevent conflict with openSUSE libtag package
* Thu Jan 31 2013 p.seiler@linuxmail.org
- corrected licenses in spec file to prevent build warning
- added devel package to prevent build error
* Wed Jan 30 2013 p.seiler@linuxmail.org
- new upstream version 12.0
  + HD audio support, including DTS-MA and Dolby True-HD, via the
  new XBMC AudioEngine
  + Live TV and PVR support
  + h.264 10bit (aka Hi10P) video software decoding for anime
  + Improved image support, allowing the database to accomodate
  numerous additional image types
  + Improved Airplay support across all platforms
  + Improved controller support
  + Advanced Filtering in the library
  + Advanced UPnP sharing
  + Translations now powered by Transifex
  Sun Apr  8 14:39:48 UTC 2012 - sagiben at gmail com
- New upstream version 11.0
* Fri Dec  9 2011 ismail@namtrac.org
- Remove _service its fragile
- Spec cleanup
* Thu Dec  8 2011 ismail@namtrac.org
- Depend on libbluray1
* Mon Nov 28 2011 sagiben@gmail.com
- fix build with gcc-4.6. Flags to the Linker must be passed via -Wl,.
  Patch was taken from xbmc ticket #11383, http://trac.xbmc.org/ticket/11383
* Tue May  3 2011 fisiu@opensuse.org
- disable-hal for openSUSE >= 11.4
* Fri Apr 15 2011 andrea@links2linux.de
- New upstream version 10.1
* Mon Jan 24 2011 andrea@links2linux.de
- enabled crystalhd and bluray support (dependencies now available)
* Mon Jan 24 2011 andrea@links2linux.de
- enabled VA-API (not sure if it works), FAAC, ssh, optimizations
* Wed Jan 12 2011 andrea@links2linux.de
- New upstream version 10.0 (Thanks fedora)
* Sun Feb  7 2010 andrea@links2linux.de
- fixed docs location
* Sat Feb  6 2010 andrea@links2linux.de
- added bool.patch to fix a startup segmentation fault
- do NOT use ffmpeg external libraries because they make xbmc crashes when you try to reproduce a video
